@@ -10,6 +10,7 @@ from metrics_layer.core.exceptions import (
 
 from .base import MetricsLayerBase
 from .field import Field
+from .filter import Filter
 from .join import Join, ZenlyticJoinRelationship, ZenlyticJoinType
 from .view import View
 
@@ -64,12 +65,49 @@ class Topic(MetricsLayerBase):
         topic_view_names = [self.base_view]
         if self.views and isinstance(self.views, dict):
             topic_view_names += list(self.views.keys())
-        return [v for v in self.project.views(model_name=self.model_name) if v.name in topic_view_names]
+
+        # Get all views - project now handles both regular views and from syntax
+        topic_views = []
+        for view_name in topic_view_names:
+            try:
+                view = self.project.get_view(view_name)
+                topic_views.append(view)
+            except AccessDeniedOrDoesNotExistException:
+                pass
+
+        return topic_views
 
     def _error(self, element, error, extra: dict = {}):
         line, column = self.line_col(element)
         return {**extra, "model_name": self.model_name, "message": error, "line": line, "column": column}
 
+    def always_filter_literal(self):
+        to_add = {"week_start_day": self.model.week_start_day, "timezone": self.project.timezone}
+        parsed_filters = []
+        if self.always_filter:
+            for f in self.always_filter:
+                if "." not in f["field"]:
+                    raise QueryError(
+                        f"Always filter field {f['field']} in the topic {self.label} needs "
+                        "to contain the view name like view_name.field_name."
+                    )
+                filter_dicts = Filter({**f, **to_add}).filter_dict(json_safe=False)
+                for filter_dict in filter_dicts:
+                    field_datatype = self.project.get_field(f["field"]).type
+                    parsed_filters.append(
+                        str(
+                            Filter.sql_query(
+                                f["field"],
+                                filter_dict["expression"],
+                                filter_dict["value"],
+                                field_datatype,
+                            )
+                        )
+                    )
+        if parsed_filters:
+            return " and ".join(parsed_filters)
+        return None
+
     def collect_errors(self):
         errors = []
 
@@ -131,8 +169,8 @@ class Topic(MetricsLayerBase):
                     )
                 )
 
-        # This value is pulled from the MAX_VIEW_DESCRIPTION_LENGTH constant in Zenlytic
-        topic_description_max_chars = 1024
+        # This value is pulled from the VIEW_DESCRIPTION_MAX_CHARS constant in Zenlytic
+        topic_description_max_chars = 2048
         if "description" in self._definition:
             if not isinstance(self.description, str):
                 errors.append(
@@ -439,6 +477,49 @@ class Topic(MetricsLayerBase):
                                     ),
                                 )
                             )
+                elif isinstance(self.base_view, str):
+                    try:
+                        # Check if the view can be joined to the base view automatically
+                        self.project.join_graph.get_join(self.base_view, view_name)
+                    except KeyError:
+                        errors.append(
+                            self._error(
+                                view_name,
+                                (
+                                    f"The view {view_name} in topic {self.label} cannot be joined "
+                                    f"automatically to the base view {self.base_view}. Please add an "
+                                    "explicit join configuration or ensure the views share common "
+                                    "identifiers that allow them to be joined."
+                                ),
+                            )
+                        )
+                # Validate 'from' property at view level
+                if "from" in view_config:
+                    from_view_name = view_config["from"]
+                    if not isinstance(from_view_name, str):
+                        errors.append(
+                            self._error(
+                                from_view_name,
+                                (
+                                    f"The from property for view {view_name} in topic {self.label} must be"
+                                    " a string referencing an existing view name"
+                                ),
+                            )
+                        )
+                    else:
+                        try:
+                            self.project.get_view(from_view_name)
+                        except AccessDeniedOrDoesNotExistException:
+                            errors.append(
+                                self._error(
+                                    from_view_name,
+                                    (
+                                        f"The from property for view {view_name} references view"
+                                        f" '{from_view_name}' which does not exist in topic {self.label}"
+                                    ),
+                                )
+                            )
+
                 if "override_access_filters" in view_config and not isinstance(
                     view_config["override_access_filters"], bool
                 ):
@@ -454,7 +535,14 @@ class Topic(MetricsLayerBase):
                 errors.extend(
                     self.invalid_property_error(
                         view_config,
-                        {"join", "override_access_filters"},
+                        {
+                            "join",
+                            "override_access_filters",
+                            "from",
+                            "label",
+                            "field_prefix",
+                            "include_metrics",
+                        },
                         "topic",
                         self.label,
                         error_func=self._error,
