@@ -369,8 +369,8 @@ class View(MetricsLayerBase, SQLReplacement):
                 )
             )
 
-        # This value is pulled from the MAX_VIEW_DESCRIPTION_LENGTH constant in Zenlytic
-        view_description_max_chars = 1024
+        # This value is pulled from the VIEW_DESCRIPTION_MAX_CHARS constant in Zenlytic
+        view_description_max_chars = 2048
         if "description" in self._definition and isinstance(self.description, str):
             if len(self.description) > view_description_max_chars:
                 errors.append(
@@ -489,7 +489,9 @@ class View(MetricsLayerBase, SQLReplacement):
                     )
                 # If the default date is not joinable to the view (or in the view itself),
                 # then we need to add an error
-                if field.view.name not in self.project.get_joinable_views(self.name) + [self.name]:
+                if field.view.name not in self.project.get_joinable_views_including_topics(self.name) + [
+                    self.name
+                ]:
                     errors.append(
                         self._error(
                             self._definition["default_date"],
