@@ -2,7 +2,12 @@ from enum import Enum
 from typing import Any, Optional
 
 from pypika import Field, Query, Table
-from pypika.dialects import MSSQLQueryBuilder, PostgreSQLQueryBuilder, QueryBuilder
+from pypika.dialects import (
+    MSSQLQueryBuilder,
+    MySQLQueryBuilder,
+    PostgreSQLQueryBuilder,
+    QueryBuilder,
+)
 from pypika.enums import Dialects
 from pypika.utils import builder, format_quotes
 
@@ -10,6 +15,8 @@ from metrics_layer.core.model.definitions import Definitions
 
 PostgreSQLQueryBuilder.ALIAS_QUOTE_CHAR = None
 PostgreSQLQueryBuilder.QUOTE_CHAR = None
+MySQLQueryBuilder.ALIAS_QUOTE_CHAR = None
+MySQLQueryBuilder.QUOTE_CHAR = None
 
 
 class NullSorting(Enum):
@@ -127,6 +134,16 @@ class SnowflakeQueryBuilderWithOrderByNullsOption(QueryBuilderWithOrderByNullsOp
         super().__init__(dialect=Dialects.SNOWFLAKE, **kwargs)
 
 
+class MySQLQuery(Query):
+    """
+    Defines a query class for use with MySQL.
+    """
+
+    @classmethod
+    def _builder(cls, **kwargs) -> "MySQLQueryBuilder":
+        return MySQLQueryBuilder(**kwargs)
+
+
 class PostgresQuery(Query):
     """
     Defines a query class for use with Snowflake.
@@ -198,6 +215,7 @@ query_lookup = {
     Definitions.trino: PostgresQueryWithOrderByNullsOption,  # trino core query logic = postgres
     Definitions.sql_server: MSSSQLQuery,
     Definitions.azure_synapse: MSSSQLQuery,  # Azure Synapse is a T-SQL flavor
+    Definitions.mysql: MySQLQuery,
 }
 
 if_null_lookup = {
@@ -211,4 +229,5 @@ if_null_lookup = {
     Definitions.trino: "coalesce",
     Definitions.sql_server: "isnull",
     Definitions.azure_synapse: "isnull",
+    Definitions.mysql: "ifnull",
 }
